@@ -1,4 +1,4 @@
-# BSD Licensed, Copyright (c) 2006-2008 MetaCarta, Inc.
+# BSD Licensed, Copyright (c) 2006-2010 TileCache Contributors
 
 import os, sys
 from warnings import warn
@@ -99,6 +99,7 @@ class Layer (object):
                   "cache", "debug", "description", 
                   "watermarkimage", "watermarkopacity",
                   "extent_type", "tms_type", "units", "mime_type",
+                  "paletted",
                   "spherical_mercator", "metadata")
     
     config_properties = [
@@ -276,8 +277,8 @@ class Layer (object):
         x0 = (minx - self.bbox[0]) / (res * self.size[0])
         y0 = (miny - self.bbox[1]) / (res * self.size[1])
         
-        x = int(round(x0))
-        y = int(round(y0))
+        x = int(x0)
+        y = int(y0)
         
         tilex = ((x * res * self.size[0]) + self.bbox[0])
         tiley = ((y * res * self.size[1]) + self.bbox[1])
@@ -351,7 +352,7 @@ class Layer (object):
         # To be implemented by subclasses
         pass 
 
-    def render (self, tile):
+    def render (self, tile, **kwargs):
         return self.renderTile(tile)
 
 class MetaLayer (Layer):
